
=============================
:mod:`oujago.datatypes.stack`
=============================

.. automodule:: oujago.datatypes.stack

.. currentmodule:: oujago.datatypes


Detailed Description
--------------------


.. autoclass:: Stack
   :members:

